Mixed-Up Code Exercises
------------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to
assess what you have learned in this chapter.

.. selectquestion:: functions_p9_sq
   :fromid: functions_p9, functions_p9_ac_q
   :toggle:

.. selectquestion:: functions_p0_sq
   :fromid: functions_p0, functions_p0_ac_q
   :toggle:

.. selectquestion:: functions_p1_sq
   :fromid: functions_p1, functions_p1_ac_q
   :toggle:

.. selectquestion:: functions_p3_sq
   :fromid: functions_p3, functions_p3_ac_q
   :toggle:

.. selectquestion:: functions_p4_sq
   :fromid: functions_p4, functions_p4_ac_q
   :toggle:

.. selectquestion:: functions_p5_sq
   :fromid: functions_p5, functions_p5_ac_q
   :toggle:

.. selectquestion:: functions_p6_sq
   :fromid: functions_p6, functions_p6_ac_q
   :toggle:

.. selectquestion:: functions_p7_sq
   :fromid: functions_p7, functions_p7_ac_q
   :toggle:

.. selectquestion:: functions_p8_sq
   :fromid: functions_p8, functions_p8_ac_q
   :toggle:

.. selectquestion:: functions_p2_sq
   :fromid: functions_p2, functions_p2_ac_q
   :toggle:
